summaryrefslogtreecommitdiff
path: root/font
diff options
context:
space:
mode:
authorG. Branden Robinson <g.branden.robinson@gmail.com>2022-07-13 02:25:09 -0500
committerG. Branden Robinson <g.branden.robinson@gmail.com>2022-07-15 21:01:05 -0500
commit5ee1e5893477273584aba3c4e25cea77c0f2d5d8 (patch)
treed092aaeff77efa08f3a3c22d19b92aca4240d0fa /font
parent89cb48d005ca8a867226be90e5f0986b7faa53be (diff)
downloadgroff-git-5ee1e5893477273584aba3c4e25cea77c0f2d5d8.tar.gz
font/devpdf/util/BuildFoundries.pl: Recast diag.
* font/devpdf/util/BuildFoundries.pl (LoadFoundry): Recast diagnostic message so that the user understands the consequence of failure to locate a Type 1 font file (that isn't one of the base 14 PostScript level 1 fonts): the font will be unavailable for the "pdf" output device.
Diffstat (limited to 'font')
-rw-r--r--font/devpdf/util/BuildFoundries.pl17
1 files changed, 11 insertions, 6 deletions
diff --git a/font/devpdf/util/BuildFoundries.pl b/font/devpdf/util/BuildFoundries.pl
index f3b460475..b1af6b0f7 100644
--- a/font/devpdf/util/BuildFoundries.pl
+++ b/font/devpdf/util/BuildFoundries.pl
@@ -116,23 +116,28 @@ sub LoadFoundry
if ($r[2] eq '')
{
- # Don't run afmtodit, just copy the grops font file
-
+ # Don't run afmtodit; just copy the groff font
+ # description file for grops.
my $gotf=1;
my $gropsfnt=LocateFile($devps,$r[0],0);
-
if ($gropsfnt ne '' and -r "$gropsfnt")
{
my $psfont=UseGropsVersion($gropsfnt);
- if (!PutDownload($psfont,LocatePF($foundrypath,$r[5]),uc($r[1])))
+ # To be embeddable in PDF, the font file name itself
+ # needs to be located and written to "download".
+ if (!PutDownload($psfont,
+ LocatePF($foundrypath,$r[5]),
+ uc($r[1])))
{
if (uc($r[1]) ne 'Y')
{
$gotf=0;
my $fns=join(', ',split('!',$r[5]));
- Warn("unable to locate font file(s): $fns");
+ Warn("groff font '$gfont' will not be"
+ . " available for PDF output; unable"
+ . " to locate font file(s): $fns");
$notFoundFont=1;
- unlink $gfont; # Unable to find the postscript file for the font just created by afmtodit
+ unlink $gfont;
}
}
Notice("Copied grops font $gfont...") if $gotf;